@@ -1,9 +1,9 @@
 #' Adding FusionCharts borders & background
-#' 
+#'
 #' \url{https://www.fusioncharts.com/dev/chart-guide/chart-configurations/border-and-background}
 #'
 #' @import htmlwidgets
-#' 
+#'
 #' @param fusionPlot fusionPlot object got by \code{fusionPlot()}
 #' @param showBorder Show the chart border
 #' @param borderColor Specify the color of the border
@@ -13,67 +13,57 @@
 #' @param bgAlphaStart,bgAlphaEnd Set the transparency of the starting ending gradient colors
 #' @param bgratioStart,bgratioEnd Set the radius of gradient colors
 #' @param bgAngle Set the angle in degrees of gradient colors
-#' 
+#'
 #' @examples
 #' library(fusionchartsR)
-#' df <- data.frame(label = c("Venezuela", "Saudi", "Canada", "Russia"), value = c(290, 260,180, 115))
+#' df <- data.frame(label = c("Venezuela", "Saudi", "Canada", "Russia"), value = c(290, 260, 180, 115))
 #' df %>%
-#' fusionPlot(x = "label", y = "value", type = "column3d") %>%
-#' fusionBackground(showBorder = TRUE, bgColorStart = "#DDDDDD") %>%
-#' fusionTheme(theme = "fusion")
+#'   fusionPlot(x = "label", y = "value", type = "column3d") %>%
+#'   fusionBackground(showBorder = TRUE, bgColorStart = "#DDDDDD") %>%
+#'   fusionTheme(theme = "fusion")
 #'
 #' @export
-fusionBackground <- function(fusionPlot, showBorder = FALSE,  borderColor = "#666666", borderThickness = "4", borderAlpha = "80", 
+fusionBackground <- function(fusionPlot, showBorder = FALSE, borderColor = "#666666", borderThickness = "4", borderAlpha = "80",
                              bgColorStart = "#ffffff", bgColorEnd = NULL, bgAlphaStart = "50", bgAlphaEnd = NULL, bgratioStart = "60", bgratioEnd = "40",
-                             bgAngle = "180"){
-  
+                             bgAngle = "180") {
   BorderBackgroundAttrs <- list()
   BorderBackgroundAttrs$showBorder <- as.numeric(showBorder)
   BorderBackgroundAttrs$borderColor <- borderColor
   BorderBackgroundAttrs$borderThickness <- borderThickness
   BorderBackgroundAttrs$borderAlpha <- borderAlpha
-  
-  if(!is.null(bgColorStart) & is.null(bgColorEnd)){
+
+  if (!is.null(bgColorStart) & is.null(bgColorEnd)) {
     BorderBackgroundAttrs$bgColor <- bgColorStart
-  }
-  else if(is.null(bgColorStart) & !is.null(bgColorEnd)){
+  } else if (is.null(bgColorStart) & !is.null(bgColorEnd)) {
     BorderBackgroundAttrs$bgColor <- bgColorEnd
-  }
-  else if(is.null(bgColorStart) & is.null(bgColorEnd)){
+  } else if (is.null(bgColorStart) & is.null(bgColorEnd)) {
     BorderBackgroundAttrs$bgColor <- "#ffffff"
-  }
-  else {
+  } else {
     BorderBackgroundAttrs$bgColor <- paste0(bgColorStart, ",", bgColorEnd)
   }
-  
-  
-  if(!is.null(bgAlphaStart) & is.null(bgAlphaEnd)){
+
+
+  if (!is.null(bgAlphaStart) & is.null(bgAlphaEnd)) {
     BorderBackgroundAttrs$bgAlpha <- bgAlphaStart
-  }
-  else if(is.null(bgAlphaStart) & !is.null(bgAlphaEnd)){
+  } else if (is.null(bgAlphaStart) & !is.null(bgAlphaEnd)) {
     BorderBackgroundAttrs$bgAlpha <- bgAlphaEnd
-  }
-  else if(is.null(bgAlphaStart) & is.null(bgAlphaEnd)){
+  } else if (is.null(bgAlphaStart) & is.null(bgAlphaEnd)) {
     BorderBackgroundAttrs$bgAlpha <- "100"
-  }
-  else {
+  } else {
     BorderBackgroundAttrs$bgAlpha <- paste0(bgAlphaStart, ",", bgAlphaEnd)
   }
-  
-  
-  if(!is.null(bgratioStart) & is.null(bgratioEnd)){
+
+
+  if (!is.null(bgratioStart) & is.null(bgratioEnd)) {
     BorderBackgroundAttrs$bgratio <- bgratioStart
-  }
-  else if(is.null(bgratioStart) & !is.null(bgratioEnd)){
+  } else if (is.null(bgratioStart) & !is.null(bgratioEnd)) {
     BorderBackgroundAttrs$bgratio <- bgratioEnd
-  }
-  else if(is.null(bgratioStart) & is.null(bgratioEnd)){
+  } else if (is.null(bgratioStart) & is.null(bgratioEnd)) {
     BorderBackgroundAttrs$bgratio <- "180"
-  }
-  else {
+  } else {
     BorderBackgroundAttrs$bgratio <- paste0(bgratioStart, ",", bgratioEnd)
   }
-  
+
   BorderBackgroundAttrs$bgAngle <- bgAngle
   # BorderBackgroundAttrs$bgImage <- bgImage
   # BorderBackgroundAttrs$bgImageAlpha <- bgImageAlpha
@@ -82,8 +72,8 @@ fusionBackground <- function(fusionPlot, showBorder = FALSE,  borderColor = "#66
   # BorderBackgroundAttrs$bgImageHAlign <- bgImageHAlign
   # BorderBackgroundAttrs$bgImageDisplayMode <- match.arg(bgImageDisplayMode)
 
-  
-  
+
+
   fusionPlot$x$showBorder <- BorderBackgroundAttrs$showBorder
   fusionPlot$x$borderColor <- BorderBackgroundAttrs$borderColor
   fusionPlot$x$borderThickness <- BorderBackgroundAttrs$borderThickness
@@ -99,7 +89,6 @@ fusionBackground <- function(fusionPlot, showBorder = FALSE,  borderColor = "#66
   # fusionPlot$x$bgImageHAlign <- BorderBackgroundAttrs$bgImageHAlign
   # fusionPlot$x$bgImageDisplayMode <- BorderBackgroundAttrs$bgImageDisplayMode
 
-  
+
   return(fusionPlot)
-  
-}
\ No newline at end of file
+}
