@@ -15,26 +15,25 @@
 #' @param numberSuffix Specify the suffix for all the Y-axis values on the chart
 #'
 #' @details A 2x2 confusion matrix can be displayed using `type = "confusionMatrix"`.
-#' 
+#'
 #' @export
 fusionPlot <- function(data, x, y, type = "column2d", numberSuffix = NULL) {
-  
   # Include unit tests
-  if(type %in% c("confusionMatrix", "heatmap")){
+  if (type %in% c("confusionMatrix", "heatmap")) {
     stopifnot(is.matrix(data))
   } else {
     stopifnot(is.data.frame(data))
     stopifnot(is.character(x))
     stopifnot(is.character(y))
   }
-  
+
   stopifnot(is.character(type))
   stopifnot(is.character(numberSuffix) | is.null(numberSuffix))
-  
+
 
   # Include key license
   license <- Sys.getenv("LICENSE_FUSIONCHARTS")
-  
+
   # Main arguments
   category <- NULL
   dataset <- NULL
@@ -42,20 +41,19 @@ fusionPlot <- function(data, x, y, type = "column2d", numberSuffix = NULL) {
   colorrange <- NULL
   columns <- NULL
   rows <- NULL
-  
-  if(type == "boxandwhisker2d"){
-    
-    xaxis <- factor(data[,x])
+
+  if (type == "boxandwhisker2d") {
+    xaxis <- factor(data[, x])
     df <- list(category = data.frame(label = as.character(levels(xaxis))))
     category <- toJSON(x = df, pretty = TRUE)
-    
+
     n <- unique(levels(xaxis))
-    df.list <- lapply(1:length(n), function(i){
-      yaxis <- na.omit(data[data[,x] == n[i],y])
+    df.list <- lapply(1:length(n), function(i) {
+      yaxis <- na.omit(data[data[, x] == n[i], y])
       stats <- boxplot.stats(yaxis)
-      if(length(stats$out) >= 1){
+      if (length(stats$out) >= 1) {
         list(
-          value = toString(yaxis[! yaxis %in% unique(stats$out)]),
+          value = toString(yaxis[!yaxis %in% unique(stats$out)]),
           outliers = toString(unique(stats$out))
         )
       } else {
@@ -64,34 +62,31 @@ fusionPlot <- function(data, x, y, type = "column2d", numberSuffix = NULL) {
         )
       }
     })
-    
+
     newlist <- list(seriesname = y, data = df.list)
     dataset <- toJSON(x = newlist, pretty = TRUE, auto_unbox = TRUE)
-    
-  } else if(type %in% c("confusionMatrix", "heatmap")){
-    
+  } else if (type %in% c("confusionMatrix", "heatmap")) {
     column01 <- list(
       column = data.frame(
         id = paste0("GROUP", colnames(data)),
         label = colnames(data)
       )
     )
-    
+
     row01 <- list(
       row = data.frame(
         id = paste0("group", rownames(data)),
         label = rownames(data)
       )
     )
-    
-    columnid <- lapply(1:length(column01$column$id), function(x){
+
+    columnid <- lapply(1:length(column01$column$id), function(x) {
       rep(column01$column$id[x], times = ncol(data))
     })
-    
-    if(type == "confusionMatrix"){
-      
+
+    if (type == "confusionMatrix") {
       mapbycategory <- "1"
-      
+
       color <- list(
         gradient = c("0", "0"),
         color = data.frame(
@@ -101,7 +96,7 @@ fusionPlot <- function(data, x, y, type = "column2d", numberSuffix = NULL) {
           label = c("Good", "Bad")
         )
       )
-      
+
       data01 <- list(
         data = data.frame(
           rowid = rep(row01$row$id, times = nrow(data)),
@@ -110,9 +105,7 @@ fusionPlot <- function(data, x, y, type = "column2d", numberSuffix = NULL) {
           colorrangelabel = c("Good", "Bad", "Bad", "Good")
         )
       )
-      
     } else {
-    
       color <- list(
         gradient = "1",
         startlabel = "Negative",
@@ -122,7 +115,7 @@ fusionPlot <- function(data, x, y, type = "column2d", numberSuffix = NULL) {
           maxvalue = c("-1", "0", "1")
         )
       )
-      
+
       data01 <- list(
         data = data.frame(
           rowid = rep(row01$row$id, times = nrow(data)),
@@ -130,38 +123,32 @@ fusionPlot <- function(data, x, y, type = "column2d", numberSuffix = NULL) {
           value = as.character(as.vector(data))
         )
       )
-      
     }
-    
+
     type <- "heatmap"
     colorrange <- toJSON(x = color, pretty = TRUE, auto_unbox = TRUE)
     columns <- toJSON(x = column01, pretty = TRUE)
     rows <- toJSON(x = row01, pretty = TRUE)
     dataset <- toJSON(x = data01, pretty = TRUE, auto_unbox = TRUE)
-    
-  }  else if(type == "scatter"){
-    
-    df <- data.frame(x = data[,x], y = data[,y])
+  } else if (type == "scatter") {
+    df <- data.frame(x = data[, x], y = data[, y])
     dataset <- toJSON(x = list(data = df), pretty = TRUE, auto_unbox = TRUE)
-    
   } else {
-    
-    new.data <- data.frame(label = factor(data[,x]), value = data[,y])
+    new.data <- data.frame(label = factor(data[, x]), value = data[, y])
     data <- toJSON(x = new.data, pretty = TRUE)
-    
   }
-  
 
 
-#' @examples
-#' library(fusionchartsR)
-#'
-#' # Single
-#' df <- data.frame(label = c("Venezuela", "Saudi", "Canada", "Russia"), value = c(290, 260,180, 115))
-#' df %>%
-#' fusionPlot(x = "label", y = "value", type = "pie2d") %>%
-#' fusionTheme(theme = "fusion")
-#' 
+
+  #' @examples
+  #' library(fusionchartsR)
+  #'
+  #' # Single
+  #' df <- data.frame(label = c("Venezuela", "Saudi", "Canada", "Russia"), value = c(290, 260,180, 115))
+  #' df %>%
+  #' fusionPlot(x = "label", y = "value", type = "pie2d") %>%
+  #' fusionTheme(theme = "fusion")
+  #'
 
   # forward options using x
   x <- list(
@@ -175,17 +162,17 @@ fusionPlot <- function(data, x, y, type = "column2d", numberSuffix = NULL) {
     rows = rows,
     colorrange = colorrange,
     mapbycategory = mapbycategory
-    )
+  )
 
   # create widget
   widgets <- htmlwidgets::createWidget(
-    name = 'fusionPlot',
+    name = "fusionPlot",
     x = x,
-    package = 'fusionchartsR'
+    package = "fusionchartsR"
   )
 
   widgets %>%
-  fusionCaption() %>%
+    fusionCaption() %>%
     fusionSubcaption() %>%
     fusionBackground() %>%
     fusionCanvas() %>%
@@ -201,7 +188,6 @@ fusionPlot <- function(data, x, y, type = "column2d", numberSuffix = NULL) {
     fusionTooltip() %>%
     fusionLogo() %>%
     fusionTheme()
-
 }
 
 
@@ -223,13 +209,15 @@ fusionPlot <- function(data, x, y, type = "column2d", numberSuffix = NULL) {
 #' @aliases renderfusionPlot
 #'
 #' @export
-fusionPlotOutput <- function(outputId, width = '100%', height = '400px'){
-  htmlwidgets::shinyWidgetOutput(outputId, 'fusionPlot', width, height, package = 'fusionchartsR')
+fusionPlotOutput <- function(outputId, width = "100%", height = "400px") {
+  htmlwidgets::shinyWidgetOutput(outputId, "fusionPlot", width, height, package = "fusionchartsR")
 }
 
 #' @rdname fusionPlotOutput
 #' @export
 renderfusionPlot <- function(expr, env = parent.frame(), quoted = FALSE) {
-  if (!quoted) { expr <- substitute(expr) } # force quoted
+  if (!quoted) {
+    expr <- substitute(expr)
+  } # force quoted
   htmlwidgets::shinyRenderWidget(expr, fusionPlotOutput, env, quoted = TRUE)
 }
